Learn R Programming

allcontributors (version 0.2.0)

allcontributors-package: allcontributors: Acknowledge all Contributors to a Project

Description

Acknowledge all contributors to a project via a single function call. The function appends to a 'README' or other specified file(s) a table with names of all individuals who contributed via code or repository issues. The package also includes several additional functions to extract and quantify contributions to any repository.

Arguments

Author

Maintainer: Mark Padgham mark.padgham@email.com

See Also