Learn R Programming

allcontributors (version 0.2.0)

get_gh_contrib_issue: get_gh_contrib_issue

Description

Extract contributors currently listed on an "All Contributions" issue in a github repository.

Usage

get_gh_contrib_issue(org, repo)

Value

Character vector of github logins for all contributors listed in current issue, or empty character string if there no issue named "All Contributors".

Arguments

org

Github organisation name for repository

repo

Repository within org for which contributors are to be extracted

See Also

Other github: get_gh_code_contributors(), get_gh_issue_people(), get_gh_issue_titles()

Examples

Run this code
if (FALSE) {
get_gh_contrib_issue (org = "ropenscilabs", repo = "allcontributors")
}

Run the code above in your browser using DataLab