Learn R Programming

allcontributors (version 0.2.0)

get_gh_issue_titles: get_gh_issue_titles

Description

Extract titles and numbers of all issues associated with a nominated repository

Usage

get_gh_issue_titles(org, repo)

Value

data.frame with one column of issue numbers, and one column of issue titles.

Arguments

org

Github organisation name for repository

repo

Repository within org for which contributors are to be extracted

See Also

Other github: get_gh_code_contributors(), get_gh_contrib_issue(), get_gh_issue_people()

Examples

Run this code
if (FALSE) {
get_gh_issue_titles (org = "ropenscilabs", repo = "allcontributors")
}

Run the code above in your browser using DataLab