powered by
Extract contributors currently listed on an "All Contributions" issue in a github repository.
get_gh_contrib_issue(org, repo)
Character vector of github logins for all contributors listed in current issue, or empty character string if there no issue named "All Contributors".
Github organisation name for repository
Repository within org for which contributors are to be extracted
org
Other github: get_gh_code_contributors(), get_gh_issue_people(), get_gh_issue_titles()
get_gh_code_contributors()
get_gh_issue_people()
get_gh_issue_titles()
if (FALSE) { get_gh_contrib_issue (org = "ropenscilabs", repo = "allcontributors") }
Run the code above in your browser using DataLab