Learn R Programming

allcontributors (version 0.2.0)

get_gh_issue_people: get_gh_issue_people

Description

Extract lists of (1) all authors of, and (2) all contributors to, all github issues for nominated repository, excluding issues closed as "not planned"

Usage

get_gh_issue_people(
  org,
  repo,
  exclude_issues = NULL,
  exclude_label = "wontfix",
  exclude_not_planned = TRUE
)

Value

List of (authors, contributors), each as character vector of github login names.

Arguments

org

Github organisation name for repository

repo

Repository within org for which contributors are to be extracted

exclude_issues

Numbers of any issues (or pull requests) to be excluded from lists of contributors.

exclude_label

Exclude any contributions from issues with specified label (default = "wontfix"; set to NULL or empty string to include all issues).

exclude_not_planned

If TRUE (default), exclude contributions to any issues closed as "not planned".

See Also

Other github: get_gh_code_contributors(), get_gh_contrib_issue(), get_gh_issue_titles()

Examples

Run this code
if (FALSE) {
get_gh_issue_people (org = "ropenscilabs", repo = "allcontributors")
}

Run the code above in your browser using DataLab