powered by
Extract lists of (1) all authors of, and (2) all contributors to, all github issues for nominated repository, excluding issues closed as "not planned"
get_gh_issue_people( org, repo, exclude_issues = NULL, exclude_label = "wontfix", exclude_not_planned = TRUE )
List of (authors, contributors), each as character vector of github login names.
Github organisation name for repository
Repository within org for which contributors are to be extracted
org
Numbers of any issues (or pull requests) to be excluded from lists of contributors.
Exclude any contributions from issues with specified label (default = "wontfix"; set to NULL or empty string to include all issues).
NULL
If TRUE (default), exclude contributions to any issues closed as "not planned".
TRUE
Other github: get_gh_code_contributors(), get_gh_contrib_issue(), get_gh_issue_titles()
get_gh_code_contributors()
get_gh_contrib_issue()
get_gh_issue_titles()
if (FALSE) { get_gh_issue_people (org = "ropenscilabs", repo = "allcontributors") }
Run the code above in your browser using DataLab