powered by
Extract titles and numbers of all issues associated with a nominated repository
get_gh_issue_titles(org, repo)
data.frame with one column of issue numbers, and one column of issue titles.
data.frame
Github organisation name for repository
Repository within org for which contributors are to be extracted
org
Other github: get_gh_code_contributors(), get_gh_contrib_issue(), get_gh_issue_people()
get_gh_code_contributors()
get_gh_contrib_issue()
get_gh_issue_people()
if (FALSE) { get_gh_issue_titles (org = "ropenscilabs", repo = "allcontributors") }
Run the code above in your browser using DataLab